@@ -10,6 +10,7 @@
 import math
 import pandas as pd
 from scipy.optimize import Bounds, LinearConstraint, minimize
+from cryptotoolbox.realtime import realtime_plotting_utility
 
 import numpy as np
 
@@ -662,3 +663,91 @@ def compute_extensive_kpis(data_df = None, strat = None):
     btd_kpis_dict['ratio_positive_year'] =ratio_positive_year
     btd_kpis_dict_df = pd.Series(btd_kpis_dict)
     return btd_kpis_dict_df, ytd_kpis, past_returns
+
+
+def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='./', plot_html=False, write_file=True):
+    if plot_html:
+        fig = realtime_plotting_utility.plot_multiple_time_series(
+            data_df=data,
+            logy=True, split=False,
+            put_on_same_scale=False,
+            title=title)
+        fig.show()
+
+    dd_list = []
+    for me_underlying in data.columns:
+        dd_display_name = 'drawdown ' + me_underlying
+        dd_list.append(dd_display_name)
+        ### whole period drawdown
+
+        dd_norm_strat = drawdown(data[me_underlying])
+        # merged_df[f'drawdown_{me_underlying}'] = dd_norm_strat
+
+        data[dd_display_name] = - dd_norm_strat
+        ### limited_period_drawdown
+        limited_dd_norm_strat = drawdown(data[me_underlying])
+        # merged_df[f'drawdown_{me_underlying}'] = dd_norm_strat
+        dd_display_name = 'drawdown ' + me_underlying.replace('close_', '')
+        data[dd_display_name] = - limited_dd_norm_strat
+
+    if plot_html:
+        fig = realtime_plotting_utility.plot_multiple_drawdowns(data, dd_list)
+        fig.show()
+    data.index = pd.to_datetime(data.index)
+    data['day'] = data.index.floor('d')
+    data = data.sort_index()
+    daily_df = data.groupby('day').first().copy()
+
+    for me_strat in daily_df.columns:
+        if not 'drawdown' in me_strat:
+            if plot_html:
+                fig = realtime_plotting_utility.plot_multiple_time_series(
+                    data_df=daily_df[[me_strat]],
+                    logy=True, split=False,
+                    put_on_same_scale=False,
+                    title= title)
+                fig.show()
+
+            if write_file:
+                writer = pd.ExcelWriter(local_root_directory + f'weekly_lo_epochs_details_{title}.xlsx',
+                                        engine='xlsxwriter')
+
+            btd_kpis, ytd_kpis, past_returns = compute_extensive_kpis(data_df=daily_df.copy(),
+                                                                                  strat=me_strat)
+            me_strat_name = me_strat
+            me_strat_name = me_strat_name.replace('0.', '')
+            # whole_period_kpi_df.to_excel(writer, sheet_name=frequency)
+            btd_kpis = btd_kpis.to_frame()
+            btd_kpis.columns = [me_strat]
+            past_returns = past_returns.to_frame()
+            past_returns.columns = [me_strat]
+            btd_kpis.to_excel(writer, sheet_name='advanced_btd')
+            ytd_kpis.to_excel(writer, sheet_name='advanced_ytd')
+            past_returns.to_excel(writer, sheet_name='common')
+            if write_file:
+                writer.save()
+            if write_file:
+                writer = pd.ExcelWriter(local_root_directory + f'{me_strat_name}_kpi_{title}.xlsx',
+                                        engine='xlsxwriter')
+                data.to_excel(writer, sheet_name='kpi')
+                writer.save()
+            ################ computing the metrics per epoch (monthly !)
+
+            daily_df['epoch_number'] = daily_df.index.year.astype(str) + '_' + daily_df.index.month.astype(str)
+
+            def compute_metrics(df, strat=None):
+                kpi_df = get_kpi(df[[strat]])
+                return kpi_df.to_dict()[strat]
+
+            go_comp_kpi = lambda x: compute_metrics(x, strat=me_strat)
+
+            epochkpis_df = daily_df[['epoch_number', me_strat]].groupby(['epoch_number']).apply(go_comp_kpi)
+
+            epochkpis_df = epochkpis_df.sort_index()
+            epochkpis_df = pd.DataFrame.from_records(epochkpis_df.to_dict()).T
+            if write_file:
+                writer = pd.ExcelWriter(local_root_directory + f'monthly_{me_strat_name}_epochs_{title}.xlsx',
+                                        engine='xlsxwriter')
+                epochkpis_df.to_excel(writer, sheet_name='kpis per epoch')
+                writer.save()
+    return data[dd_list]
